# sosi_api

SoSimple API client.

A simple, base for building REST API client wrappers in Python.

DOCS:

- [Installing](docs/installing.md)
- [Extending](docs/extending.md)
- [Contributing](docs/contributing.md)
